==> gwtupload-1.0.0.jar: gwtupload/shared/UConsts.java <==
package gwtupload.shared;

public class UConsts {
  public static final String TAG_BLOBSTORE_PATH = "blobpath";
  public static final String TAG_BLOBSTORE = "blobstore";
  public static final String TAG_KEY = "key";
  public static final String TAG_CANCELED = "canceled";
  public static final String TAG_CTYPE = "ctype";
  public static final String TAG_CURRENT_BYTES = "currentBytes";
  public static final String TAG_DELETED = "deleted";
  public static final String TAG_ERROR = "error";
  public static final String TAG_FIELD = "field";
  public static final String TAG_FINISHED = "finished";
  public static final String TAG_MESSAGE = "message";
  public static final String TAG_NAME = "name";
  public static final String TAG_PERCENT = "percent";
  public static final String TAG_SIZE = "size";
  public static final String TAG_TOTAL_BYTES = "totalBytes";
  public static final String TAG_WAIT = "wait";
  public static final String TAG_OK = "ok";
  public static final String TAG_FILE = "file";
  public static final String TAG_FILES = "files";
  public static final String TAG_VALUE = "value";
  public static final String TAG_PARAM = "parameter";
  public static final String TAG_PARAMS = "parameters";
  public static final String TAG_SESSION_ID = "sessionid";
  
  public static final String TAG_MSG_START = "%%%INI%%%";
  public static final String TAG_MSG_END = "%%%END%%%";
  public static final String TAG_MSG_GT = "^^^@@";
  public static final String TAG_MSG_LT = "@@^^^";
  
  public static final String PARAM_BLOBSTORE = TAG_BLOBSTORE;
  public static final String PARAM_BLOBKEY = "blob-key";
  public static final String PARAM_CANCEL = "cancel";
  public static final String PARAM_CLEAN = "clean";
  public static final String PARAM_DELAY = "delay";
  public static final String PARAM_FILENAME = "filename";
  public static final String PARAM_REMOVE = "remove";
  public static final String PARAM_SESSION = "new_session";
  public static final String PARAM_SHOW = "show";
  public static final String PARAM_CTYPE = "ctype";
  public static final String PARAM_MESSAGE = TAG_MESSAGE;
  public static final String PARAM_ERROR = TAG_ERROR;
  public static final String PARAM_REDIRECT = "redirect";
  
  public static final String MULTI_SUFFIX = "[]";
  
  public static final String RESP_OK = "ok";
}

==> gwtupload-1.0.3.jar: gwtupload/shared/UConsts.java <==
package gwtupload.shared;

public class UConsts {
  public static final String TAG_BLOBSTORE_PATH = "blobpath";
  public static final String TAG_BLOBSTORE_NAME = "blobname";
  public static final String TAG_BLOBSTORE_PARAM = "blobparam";
  public static final String ATTR_BLOBSTORE_PARAM_NAME = "name";
  public static final String TAG_BLOBSTORE = "blobstore";
  public static final String TAG_KEY = "key";
  public static final String TAG_CANCELED = "canceled";
  public static final String TAG_CTYPE = "ctype";
  public static final String TAG_CURRENT_BYTES = "currentBytes";
  public static final String TAG_DELETED = "deleted";
  public static final String TAG_ERROR = "error";
  public static final String TAG_FIELD = "field";
  public static final String TAG_FINISHED = "finished";
  public static final String TAG_MESSAGE = "message";
  public static final String TAG_NAME = "name";
  public static final String TAG_PERCENT = "percent";
  public static final String TAG_SIZE = "size";
  public static final String TAG_TOTAL_BYTES = "totalBytes";
  public static final String TAG_WAIT = "wait";
  public static final String TAG_OK = "ok";
  public static final String TAG_FILE = "file";
  public static final String TAG_FILES = "files";
  public static final String TAG_VALUE = "value";
  public static final String TAG_PARAM = "parameter";
  public static final String TAG_PARAMS = "parameters";
  public static final String TAG_SESSION_ID = "sessionid";

  public static final String TAG_MSG_START = "%%%INI%%%";
  public static final String TAG_MSG_END = "%%%END%%%";
  public static final String TAG_MSG_GT = "^^^@@";
  public static final String TAG_MSG_LT = "@@^^^";

  public static final String PARAM_BLOBSTORE = TAG_BLOBSTORE;
  public static final String PARAM_BLOBKEY = "blob-key";
  public static final String PARAM_CANCEL = "cancel";
  public static final String PARAM_CLEAN = "clean";
  public static final String PARAM_DELAY = "delay";
  public static final String PARAM_FILENAME = "filename";
  public static final String PARAM_NAME = "name";
  public static final String PARAM_REMOVE = "remove";
  public static final String PARAM_SESSION = "new_session";
  public static final String PARAM_SHOW = "show";
  public static final String PARAM_CTYPE = "ctype";
  public static final String PARAM_MESSAGE = TAG_MESSAGE;
  public static final String PARAM_ERROR = TAG_ERROR;
  public static final String PARAM_REDIRECT = "redirect";

  public static final String MULTI_SUFFIX = "[]";

  public static final String RESP_OK = "ok";
}
